@@ -3,7 +3,9 @@
 Version code adopted from Django development version.
 https://github.com/django/django
 """
-VERSION = (0, 17, 3, 'final', 0)
+
+VERSION = (0, 17, 6, 'final', 0)
+
 default_app_config = 'modeltranslation.apps.ModeltranslationConfig'
 
 
@@ -54,9 +56,13 @@ def get_git_changeset():
 
     repo_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
     git_log = subprocess.Popen(
-        'git log --pretty=format:%ct --quiet -1 HEAD', stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE, shell=True, cwd=repo_dir,
-        universal_newlines=True)
+        'git log --pretty=format:%ct --quiet -1 HEAD',
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+        shell=True,
+        cwd=repo_dir,
+        universal_newlines=True,
+    )
     timestamp = git_log.communicate()[0]
     try:
         timestamp = datetime.datetime.utcfromtimestamp(int(timestamp))
